@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 #  gcompris - gnumch
 #
-# Time-stamp: <2005/10/03 09:16 Joe Neeman>
+# Time-stamp: <2007-08-22 01:26:11 bruno>
 #
 # Copyright (C) 2005 Joe Neeman
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation; either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -16,10 +16,10 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#   along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 
+import gobject
 import gnomecanvas
 import gcompris
 import gcompris.utils
@@ -27,12 +27,13 @@ import gcompris.skin
 import gcompris.bonus
 import gcompris.score
 import gcompris.anim
+import gcompris.sound
 import gobject
 import gtk
 import gtk.gdk
 import random
 import math
-from gettext import gettext as _
+from gcompris import gcompris_gettext as _
 
 class Number:
     def __init__(self, text, good):
@@ -147,13 +148,16 @@ class FactorLevelset:
         self.nonfactors = []
 
     def getError(self, num):
-        fmt = _('Multiples of %d include %s,\nbut %d is not a multiple of %d.')
+        # Translators: You can swap %(x)y elements in the string.
+        fmt = _('Multiples of %(d1)d include %(s)s,\nbut %(d2)d is not a multiple of %(d3)d.')
         n = int(num.text)
         mults = []
         for i in range(2, 5):
             mults.append(n*i)
-        s = makeNumList(mults) % tuple(mults)
-        return fmt % (n, s, self.level_multiple[self.cur_sublevel-1], n)
+        return fmt % { 'd1': n,
+                       's': makeNumList(mults) % tuple(mults),
+                       'd2': self.level_multiple[self.cur_sublevel-1],
+                       'd3': n }
 
     def getTitle(self):
         return _('Factors of %d') % ( self.level_multiple[self.cur_sublevel-1] )
@@ -321,10 +325,10 @@ class Player(object):
 
     def die(self):
         if self.movestep_timer != 0:
-            gtk.timeout_remove(self.movestep_timer)
+            gobject.source_remove(self.movestep_timer)
             self.movestep_timer = 0
         if self.munch_timer != 0:
-            gtk.timeout_remove(self.munch_timer)
+            gobject.source_remove(self.munch_timer)
             self.munch_timer = 0
 
     def getEaten(self):
@@ -359,6 +363,7 @@ class Player(object):
         return ret
 
     def move(self, x_old, y_old, x, y):
+        gcompris.sound.play_ogg("sounds/smudge.wav")
         self.x_old = x_old
         self.y_old = y_old
         self.x = x
@@ -376,6 +381,7 @@ class Player(object):
             self.stop()
 
     def startMunching(self):
+        gcompris.sound.play_ogg("sounds/eat.wav")
         self.anim.setState(2)
         self.munch_timer = game.timeout_add(game.munch_time, self.stopMunching)
         return False
@@ -541,7 +547,7 @@ class Troggle(Player):
         self.nextspawn_timer = game.timeout_add( time + game.trogwarn_time, self.spawn )
         self.warn_timer = game.timeout_add( time, game.show_trogwarning )
         if self.nextmove_timer != 0:
-            gtk.timeout_remove(self.nextmove_timer)
+            gobject.source_remove(self.nextmove_timer)
             self.nextmove_timer = 0
 
     def getEaten(self):
@@ -756,7 +762,7 @@ class Gcompris_gnumch:
         # the board title
         self.title = self.rootitem.add(gnomecanvas.CanvasText,
                                        text = "",
-                                       font = gcompris.skin.get_font("gcompris/board/huge bold"),
+                                       font = gcompris.skin.get_font("gcompris/board/title bold"),
                                        x = self.scrw/2,
                                        y = self.top/2)
 
@@ -767,7 +773,7 @@ class Gcompris_gnumch:
         self.message = self.rootitem.add(gnomecanvas.CanvasText,
                                         text = "",
                                         justification = gtk.JUSTIFY_CENTER,
-                                        font = gcompris.skin.get_font("gcompris/board/huge bold"),
+                                        font = gcompris.skin.get_font("gcompris/board/title bold"),
                                         x = self.scrw/2,
                                         y = self.scrh/2)
         self.message.hide()
@@ -776,7 +782,7 @@ class Gcompris_gnumch:
         self.trogwarning = self.rootitem.add(gnomecanvas.CanvasText,
                                         text = _("T\nR\nO\nG\nG\nL\nE"),
                                         justification = gtk.JUSTIFY_CENTER,
-                                        font = gcompris.skin.get_font("gcompris/board/huge bold"),
+                                        font = gcompris.skin.get_font("gcompris/board/title bold"),
                                         x = self.left/2,
                                         y = self.scrh/2)
         self.trogwarning.hide()
@@ -845,14 +851,14 @@ class Gcompris_gnumch:
     def stopGame(self):
         self.stopped = 1
         if self.muncher.munch_timer != 0:
-            gtk.timeout_remove(self.muncher.munch_timer)
+            gobject.source_remove(self.muncher.munch_timer)
         if self.muncher.movestep_timer != 0:
-            gtk.timeout_remove(self.muncher.movestep_timer)
+            gobject.source_remove(self.muncher.movestep_timer)
 
         for t in self.troggles:
             for timer in [t.munch_timer, t.movestep_timer, t.nextmove_timer, t.nextspawn_timer, t.warn_timer]:
                 if timer != 0:
-                    gtk.timeout_remove(timer)
+                    gobject.source_remove(timer)
 
     def startGame(self):
         self.stopped = 0
@@ -913,7 +919,7 @@ class Gcompris_gnumch:
 
     def timeout_add(self, t, fn):
         if not self.paused and not self.stopped:
-            return gtk.timeout_add(t, fn)
+            return gobject.timeout_add(t, fn)
         else:
             return 0
 
